markuptools.get_markup_attached_to_component
============================================

.. autofunction:: abjad.tools.markuptools.get_markup_attached_to_component.get_markup_attached_to_component
   :noindex:
